@@ -166,9 +166,6 @@ remove_folder (ExchangeHierarchy *hier, EFolder *folder)
 		EXCHANGE_HIERARCHY_FAVORITES (hier);
 	const char *folder_uri, *shortcut_uri;
 	E2kHTTPStatus status;
-	char *conf_key_cal="/apps/evolution/calendar/sources";
-	char *conf_key_tasks="/apps/evolution/tasks/sources";
-	char *conf_key_contacts="/apps/evolution/addressbook/sources";
 	ESourceList *cal_source_list, *task_source_list, *cont_source_list;
 	const char *folder_type, *physical_uri;
 
@@ -194,27 +191,27 @@ remove_folder (ExchangeHierarchy *hier, EFolder *folder)
 	if (strcmp (folder_type, "calendar") == 0) {
 		cal_source_list = e_source_list_new_for_gconf (
 					gconf_client_get_default (),
-					conf_key_cal);
-		remove_esource (hier->account, conf_key_cal, physical_uri,
-				&cal_source_list, FALSE, FALSE);
+					CONF_KEY_CAL);
+		remove_esource (hier->account, EXCHANGE_CALENDAR_FOLDER, 
+				physical_uri, &cal_source_list, FALSE);
 		e_source_list_sync (cal_source_list, NULL);
 		g_object_unref (cal_source_list);
 	}
 	else if (strcmp (folder_type, "tasks") == 0) {
 		task_source_list = e_source_list_new_for_gconf (
 					gconf_client_get_default (),
-					conf_key_tasks);
-		remove_esource (hier->account, conf_key_tasks, physical_uri,
-				&task_source_list, FALSE, FALSE);
+					CONF_KEY_TASKS);
+		remove_esource (hier->account, EXCHANGE_TASKS_FOLDER, 
+				physical_uri, &task_source_list, FALSE);
 		e_source_list_sync (task_source_list, NULL);
 		g_object_unref (task_source_list);
 	}
 	else if (strcmp (folder_type, "contacts") == 0) {
 		cont_source_list = e_source_list_new_for_gconf (
 					gconf_client_get_default (),
-					conf_key_contacts);
-		remove_esource (hier->account, conf_key_contacts, physical_uri,
-					&cont_source_list, FALSE, TRUE);
+					CONF_KEY_CONTACTS);
+		remove_esource (hier->account, EXCHANGE_CONTACTS_FOLDER, 
+				physical_uri, &cont_source_list, FALSE);
 		e_source_list_sync (cont_source_list, NULL);
 		g_object_unref (cont_source_list);
 	}
@@ -238,7 +235,7 @@ exchange_hierarchy_favorites_add_folder (ExchangeHierarchy *hier,
 	ExchangeHierarchyFavorites *hfav;
 	E2kProperties *props;
 	E2kHTTPStatus status;
-	const char *folder_uri;
+	const char *folder_uri, *permanent_uri;
 	char *shortcut_uri;
 
 	g_return_val_if_fail (EXCHANGE_IS_HIERARCHY (hier), EXCHANGE_ACCOUNT_FOLDER_GENERIC_ERROR);
@@ -246,12 +243,14 @@ exchange_hierarchy_favorites_add_folder (ExchangeHierarchy *hier,
 	g_return_val_if_fail (e_folder_exchange_get_hierarchy (folder)->type == EXCHANGE_HIERARCHY_PUBLIC, EXCHANGE_ACCOUNT_FOLDER_GENERIC_ERROR);
 
 	hfav = EXCHANGE_HIERARCHY_FAVORITES (hier);
+	permanent_uri = e_folder_exchange_get_permanent_uri (folder);
 
 	props = e2k_properties_new ();
 	e2k_properties_set_string (props, PR_FAV_DISPLAY_NAME,
 				   g_strdup (e_folder_get_name (folder)));
-	e2k_properties_set_binary (props, PR_FAV_PUBLIC_SOURCE_KEY,
-				   e2k_permanenturl_to_entryid (e_folder_exchange_get_permanent_uri (folder)));
+	if (permanent_uri)	
+		e2k_properties_set_binary (props, PR_FAV_PUBLIC_SOURCE_KEY,
+				   e2k_permanenturl_to_entryid (permanent_uri));
 	e2k_properties_set_int (props, PR_FAV_LEVEL_MASK, 1);
 
 	status = e2k_context_proppatch_new (
